@@ -9,7 +9,7 @@ use Cpanel::JSON::XS;
 
 use overload '""' => \&to_string, fallback => 1;
 
-sub TO_JSON { }
+sub TO_JSON { Carp::croak 'TO_JSON is not extended by subclass' }
 
 sub to_string {
 
@@ -25,8 +25,11 @@ sub to_string {
 sub to_hash {
 
     my $self = shift;
+
     my $json = $self->to_string;
-    return Cpanel::JSON::XS->new->decode($json);
+    my $hash = Cpanel::JSON::XS->new->decode($json);
+
+    return $hash;
 
 }
 
