@@ -5,9 +5,9 @@ use strict;
 use warnings;
 use utf8;
 
+use SBOM::CycloneDX::Enum;
 use SBOM::CycloneDX::Hash;
 use SBOM::CycloneDX::List;
-use SBOM::CycloneDX::Enum;
 
 use Types::Standard qw(Str Enum Num);
 use Types::TypeTiny qw(ArrayLike);
@@ -17,25 +17,26 @@ use namespace::autoclean;
 
 extends 'SBOM::CycloneDX::Base';
 
-has primitive                => (is => 'rw', isa => Enum [SBOM::CycloneDX::Enum->CRYPTO_PRIMITIVES()]);
+has primitive                => (is => 'rw', isa => Enum [SBOM::CycloneDX::Enum->values('CRYPTO_PRIMITIVE')]);
 has algorithm_family         => (is => 'rw', isa => Str);
 has parameter_set_identifier => (is => 'rw', isa => Str);
 has curve                    => (is => 'rw', isa => Str);
 has execution_environment    => (is => 'rw', isa => Str);
-has implementation_platform  => (is => 'rw', isa => Enum [SBOM::CycloneDX::Enum->CRYPTO_IMPLEMENTATION_PLATFORMS()]);
+has implementation_platform =>
+    (is => 'rw', isa => Enum [SBOM::CycloneDX::Enum->values('CRYPTO_IMPLEMENTATION_PLATFORM')]);
 
 has certification_level => (
     is      => 'rw',
-    isa     => ArrayLike [Enum [SBOM::CycloneDX::Enum->CRYPTO_CERTIFICATION_LEVELS()]],
+    isa     => ArrayLike [Enum [SBOM::CycloneDX::Enum->values('CRYPTO_CERTIFICATION_LEVEL')]],
     default => sub { SBOM::CycloneDX::List->new }
 );
 
-has mode    => (is => 'rw', isa => Enum [SBOM::CycloneDX::Enum->CRYPTO_MODES()]);
-has padding => (is => 'rw', isa => Enum [SBOM::CycloneDX::Enum->CRYPTO_PADDINGS()]);
+has mode    => (is => 'rw', isa => Enum [SBOM::CycloneDX::Enum->values('CRYPTO_MODE')]);
+has padding => (is => 'rw', isa => Enum [SBOM::CycloneDX::Enum->values('CRYPTO_PADDING')]);
 
 has crypto_functions => (
     is      => 'rw',
-    isa     => ArrayLike [Enum [SBOM::CycloneDX::Enum->CRYPTO_FUNCTIONS()]],
+    isa     => ArrayLike [Enum [SBOM::CycloneDX::Enum->values('CRYPTO_FUNCTION')]],
     default => sub { SBOM::CycloneDX::List->new }
 );
 
@@ -97,54 +98,54 @@ Properties:
 
 =over
 
-=item C<algorithm_family>, A valid algorithm family identifier. If specified,
+=item * C<algorithm_family>, A valid algorithm family identifier. If specified,
 this value must be one of the enumeration of valid algorithm Family identifiers
 defined in the C<cryptography-defs.schema.json> subschema.
 
-=item C<certification_level>, The certification that the implementation of
+=item * C<certification_level>, The certification that the implementation of
 the cryptographic algorithm has received, if any. Certifications include
 revisions and levels of FIPS 140 or Common Criteria of different Extended
 Assurance Levels (CC-EAL).
 
-=item C<classical_security_level>, The classical security level that a
+=item * C<classical_security_level>, The classical security level that a
 cryptographic algorithm provides (in bits).
 
-=item C<crypto_functions>, The cryptographic functions implemented by the
+=item * C<crypto_functions>, The cryptographic functions implemented by the
 cryptographic algorithm.
 
-=item C<curve>, [Deprecated] The specific underlying Elliptic Curve (EC) definition
+=item * C<curve>, [Deprecated] The specific underlying Elliptic Curve (EC) definition
 employed which is an indicator of the level of security strength,
 performance and complexity. Absent an authoritative source of curve names,
 CycloneDX recommends using curve names as defined at
 L<https://neuromancer.sk/std/>, the source of
 which can be found at L<https://github.com/J08nY/std-curves>.
 
-=item C<execution_environment>, The target and execution environment in
+=item * C<execution_environment>, The target and execution environment in
 which the algorithm is implemented in.
 
-=item C<implementation_platform>, The target platform for which the
+=item * C<implementation_platform>, The target platform for which the
 algorithm is implemented. The implementation can be 'generic', running on
 any platform or for a specific platform.
 
-=item C<mode>, The mode of operation in which the cryptographic algorithm
+=item * C<mode>, The mode of operation in which the cryptographic algorithm
 (block cipher) is used.
 
-=item C<nist_quantum_security_level>, The NIST security strength category
+=item * C<nist_quantum_security_level>, The NIST security strength category
 as defined in
 L<https://csrc.nist.gov/projects/post-quantum-cryptography/post-quantum-crypt
 ography-standardization/evaluation-criteria/security-(evaluation-criteria)>.
 A value of 0 indicates that none of the categories are met.
 
-=item C<padding>, The padding scheme that is used for the cryptographic
+=item * C<padding>, The padding scheme that is used for the cryptographic
 algorithm.
 
-=item C<parameter_set_identifier>, An identifier for the parameter set of
+=item * C<parameter_set_identifier>, An identifier for the parameter set of
 the cryptographic algorithm. Examples: in AES128, '128' identifies the key
 length in bits, in SHA256, '256' identifies the digest length, '128' in
 SHAKE128 identifies its maximum security level in bits, and 'SHA2-128s'
 identifies a parameter set used in SLH-DSA (FIPS205).
 
-=item C<primitive>, Cryptographic building blocks used in higher-level
+=item * C<primitive>, Cryptographic building blocks used in higher-level
 cryptographic systems and protocols. Primitives represent different
 cryptographic routines: deterministic random bit generators (drbg, e.g.
 CTR_DRBG from NIST SP800-90A-r1), message authentication codes (mac, e.g.
