@@ -5,28 +5,26 @@ use strict;
 use warnings;
 use utf8;
 
+use SBOM::CycloneDX::Enum;
 use SBOM::CycloneDX::Timestamp;
+
 use Types::Standard qw(Str Enum InstanceOf);
+use Types::TypeTiny qw(ArrayLike);
 
 use Moo;
 use namespace::autoclean;
 
 extends 'SBOM::CycloneDX::Base';
 
-has state => (
-    is  => 'rw',
-    isa => Enum [qw(resolved resolved_with_pedigree exploitable in_triage false_positive not_affected)]
-);
+has state => (is => 'rw', isa => Enum [SBOM::CycloneDX::Enum->values('IMPACT_ANALYSIS_STATE')]);
 
-has justification => (
-    is  => 'rw',
-    isa => Enum [qw(
-        code_not_present code_not_reachable requires_configuration requires_dependency requires_environment
-        protected_by_compiler protected_at_runtime protected_at_perimeter protected_by_mitigating_control
-    )]
-);
+has justification => (is => 'rw', isa => Enum [SBOM::CycloneDX::Enum->values('IMPACT_ANALYSIS_JUSTIFICATION')]);
 
-has response => (is => 'rw', isa => Enum [qw(can_not_fix will_not_fix update rollback workaround_available)]);
+has response => (
+    is      => 'rw',
+    isa     => ArrayLike [Enum [qw(can_not_fix will_not_fix update rollback workaround_available)]],
+    default => sub { SBOM::CycloneDX::List->new }
+);
 
 has detail => (is => 'rw', isa => Str);
 
@@ -90,25 +88,25 @@ Properties:
 
 =over
 
-=item C<detail>, Detailed description of the impact including methods used
+=item * C<detail>, Detailed description of the impact including methods used
 during assessment. If a vulnerability is not exploitable, this field should
 include specific details on why the component or service is not impacted by
 this vulnerability.
 
-=item C<first_issued>, The date and time (timestamp) when the analysis was
+=item * C<first_issued>, The date and time (timestamp) when the analysis was
 first issued.
 
-=item C<justification>, The rationale of why the impact analysis state was asserted.
+=item * C<justification>, The rationale of why the impact analysis state was asserted.
 
-=item C<last_updated>, The date and time (timestamp) when the analysis was
+=item * C<last_updated>, The date and time (timestamp) when the analysis was
 last updated.
 
-=item C<response>, A response to the vulnerability by the manufacturer,
+=item * C<response>, A response to the vulnerability by the manufacturer,
 supplier, or project responsible for the affected component or service.
 More than one response is allowed. Responses are strongly encouraged for
 vulnerabilities where the analysis state is exploitable.
 
-=item C<state>, Declares the current state of an occurrence of a vulnerability,
+=item * C<state>, Declares the current state of an occurrence of a vulnerability,
 after automated or manual analysis.
 
 =back
